@@ -10,7 +10,7 @@ A rule can be a callback or a variable that will be evaluated as bool.
 """
 import logging
 
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_unicode
 
 from exceptions import Denied, DoesNotExist
 
@@ -80,10 +80,11 @@ class RuleRegistry(dict):
 
         formated_args = []
         for arg in args:
-            formated_args.append(u'"%s"' % smart_text(arg))
+            formated_args.append(u'"%s"' % smart_unicode(arg))
 
         for key, value in kwargs.items():
-            formated_args.append(u'%s="%s"' % (smart_text(key), smart_text(value)))
+            formated_args.append(u'%s="%s"' % (smart_unicode(key),
+                smart_unicode(value)))
         formated_args = u', '.join(formated_args)
 
         if hasattr(self[name], '__call__'):
@@ -101,12 +102,16 @@ class RuleRegistry(dict):
     def rule_text_name(self, rule):
         if hasattr(rule, 'func_name'):
             return rule.func_name
+        elif rule is True:
+            return u'True'
+        elif rule is False:
+            return u'False'
         elif hasattr(rule, '__class__'):
             return rule.__class__.__name__
         elif hasattr(rule, '__name__'):
             return rule.__name__
         else:
-            return smart_text(rule)
+            return smart_unicode(rule)
 
 
 registry = RuleRegistry()
