@@ -1,4 +1,5 @@
 from registry import RegistryTestCase
-from class_decorator import DecoratorTestCase
+from class_decorator import ClassDecoratorTestCase
 from autodiscover import AutodiscoverTestCase
 from views import ViewsTestCase
+from decorators import DecoratorsTestCase
